@@ -5,7 +5,7 @@ use warnings;
 use LWP::UserAgent;
 use JSON::MaybeXS;
 
-our $VERSION = 0.09;
+our $VERSION = 0.10;
 
 sub new {
     my ( $class, %params ) = @_;
@@ -125,48 +125,80 @@ The endpoint URL for the OpenAI API. Default: 'https://api.openai.com/v1/'.
 
 Given a prompt, the model will return one or more predicted completions.
 
-Documentation: L<Completions|https://platform.openai.com/docs/api-reference/completions>
-
 =over 4
 
 =item * model
 
-The name of the language model to use.
+ID of the model to use.
 
-See 'https://platform.openai.com/docs/api-reference/models'.
+See L<Models overview|https://platform.openai.com/docs/models/overview>
+for a reference of them.
 
 =item * prompt
 
 The prompt for the text generation.
 
+=item * suffix [optional]
+
+The suffix that comes after a completion of inserted text.
+
 =item * max_tokens [optional]
 
 The maximum number of tokens to generate.
 
+Most models have a context length of 2048 tokens (except for the newest
+models, which support 4096.
+
 =item * temperature [optional]
 
-The temperature to use for sampling.
+What sampling temperature to use, between 0 and 2. Higher values like
+0.8 will make the output more random, while lower values like 0.2 will
+make it more focused and deterministic.
 
 =item * top_p [optional]
 
-The top-p value to use for sampling.
+An alternative to sampling with temperature, called nucleus sampling.
+
+We generally recommend altering this or C<temperature> but not both.
+
+=item * n [optional]
+
+How many completions to generate for each prompt.
+
+Use carefully and ensure that you have reasonable settings for
+C<max_tokens> and C<stop>.
+
+=item * stop [optional]
+
+Up to 4 sequences where the API will stop generating further tokens. The
+returned text will not contain the stop sequence.
 
 =item * frequency_penalty [optional]
 
-The frequency penalty to use for sampling.
+Number between -2.0 and 2.0. Positive values penalize new tokens based
+on their existing frequency in the text so far.
 
 =item * presence_penalty [optional]
 
-The presence penalty to use for sampling.
+Number between -2.0 and 2.0. Positive values penalize new tokens based
+on whether they appear in the text so far.
+
+=item * best_of [optional]
+
+Generates best_of completions server-side and returns the "best" (the
+one with the highest log probability per token).
+
+Use carefully and ensure that you have reasonable settings for
+C<max_tokens> and C<stop>.
 
 =back
 
+Documentation: L<Completions|https://platform.openai.com/docs/api-reference/completions>
+
 =head2 edits()
 
 Creates a new edit for the provided input, instruction, and parameters.
 
-Documentation: L<Edits|https://platform.openai.com/docs/api-reference/edits>
-
 =over 4
 
 =item * model
@@ -196,13 +228,13 @@ An alternative to sampling with temperature.
 
 =back
 
+Documentation: L<Edits|https://platform.openai.com/docs/api-reference/edits>
+
 =head2 embeddings()
 
 Get a vector representation of a given input that can be easily consumed
 by machine learning models and algorithms.
 
-Documentation: L<Embeddings|https://platform.openai.com/docs/api-reference/embeddings>
-
 =over 4
 
 =item * model
@@ -213,13 +245,13 @@ Documentation: L<Embeddings|https://platform.openai.com/docs/api-reference/embed
 
 =back
 
+Documentation: L<Embeddings|https://platform.openai.com/docs/api-reference/embeddings>
+
 =head2 moderations()
 
 Given a input text, outputs if the model classifies it as violating
 OpenAI's content policy.
 
-Documentation: L<Moderations|https://platform.openai.com/docs/api-reference/moderations>
-
 =over 4
 
 =item * input
@@ -228,13 +260,15 @@ Documentation: L<Moderations|https://platform.openai.com/docs/api-reference/mode
 
 =back
 
+Documentation: L<Moderations|https://platform.openai.com/docs/api-reference/moderations>
+
 =head1 SEE ALSO
 
 L<OpenAI Reference Overview|https://platform.openai.com/docs/api-reference/overview>
 
 =head1 AUTHOR
 
-Nelson Ferraz <lt>nferraz@gmail.comE<gt>
+Nelson Ferraz E<lt>nferraz@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
